package cn.com.infosec.jce;

import cn.com.infosec.asn1.ASN1EncodableVector;
import cn.com.infosec.asn1.DERBitString;
import cn.com.infosec.asn1.DEREncodable;
import cn.com.infosec.asn1.DERInteger;
import cn.com.infosec.asn1.DERObjectIdentifier;
import cn.com.infosec.asn1.DEROctetString;
import cn.com.infosec.asn1.DEROutputStream;
import cn.com.infosec.asn1.DERSequence;
import cn.com.infosec.asn1.DERUTCTime;
import cn.com.infosec.asn1.x509.AlgorithmIdentifier;
import cn.com.infosec.asn1.x509.CertificateList;
import cn.com.infosec.asn1.x509.TBSCertList;
import cn.com.infosec.asn1.x509.V2TBSCertListGenerator;
import cn.com.infosec.asn1.x509.X509Extension;
import cn.com.infosec.asn1.x509.X509Extensions;
import cn.com.infosec.asn1.x509.X509Name;
import cn.com.infosec.jce.provider.X509CRLObject;
import cn.com.infosec.util.Strings;
import java.io.ByteArrayOutputStream;
import java.io.IOException;
import java.math.BigInteger;
import java.security.NoSuchAlgorithmException;
import java.security.NoSuchProviderException;
import java.security.PrivateKey;
import java.security.SecureRandom;
import java.security.Signature;
import java.security.cert.CRLException;
import java.security.cert.X509CRL;
import java.text.SimpleDateFormat;
import java.util.Date;
import java.util.Hashtable;
import java.util.SimpleTimeZone;
import java.util.Vector;

/** @deprecated */
public class X509V2CRLGenerator {
   private static Hashtable algorithms;
   private SimpleDateFormat dateF;
   private SimpleTimeZone tz;
   private V2TBSCertListGenerator tbsGen;
   private DERObjectIdentifier sigOID;
   private AlgorithmIdentifier sigAlgId;
   private String signatureAlgorithm;
   private Hashtable extensions;
   private Vector extOrdering;

   static {
      Hashtable var10000 = algorithms = new Hashtable();
      DERObjectIdentifier var0;
      var0 = new DERObjectIdentifier.<init>("1.2.840.113549.1.1.2");
      var10000.put("MD2WITHRSAENCRYPTION", var0);
      var10000 = algorithms;
      var0 = new DERObjectIdentifier.<init>("1.2.840.113549.1.1.2");
      var10000.put("MD2WITHRSA", var0);
      var10000 = algorithms;
      var0 = new DERObjectIdentifier.<init>("1.2.840.113549.1.1.4");
      var10000.put("MD5WITHRSAENCRYPTION", var0);
      var10000 = algorithms;
      var0 = new DERObjectIdentifier.<init>("1.2.840.113549.1.1.4");
      var10000.put("MD5WITHRSA", var0);
      var10000 = algorithms;
      var0 = new DERObjectIdentifier.<init>("1.2.840.113549.1.1.5");
      var10000.put("SHA1WITHRSAENCRYPTION", var0);
      var10000 = algorithms;
      var0 = new DERObjectIdentifier.<init>("1.2.840.113549.1.1.5");
      var10000.put("SHA1WITHRSA", var0);
      var10000 = algorithms;
      var0 = new DERObjectIdentifier.<init>("1.3.36.3.3.1.2");
      var10000.put("RIPEMD160WITHRSAENCRYPTION", var0);
      var10000 = algorithms;
      var0 = new DERObjectIdentifier.<init>("1.3.36.3.3.1.2");
      var10000.put("RIPEMD160WITHRSA", var0);
      var10000 = algorithms;
      var0 = new DERObjectIdentifier.<init>("1.2.840.10040.4.3");
      var10000.put("SHA1WITHDSA", var0);
      var10000 = algorithms;
      var0 = new DERObjectIdentifier.<init>("1.2.840.10040.4.3");
      var10000.put("DSAWITHSHA1", var0);
      var10000 = algorithms;
      var0 = new DERObjectIdentifier.<init>("1.2.840.10045.4.1");
      var10000.put("SHA1WITHECDSA", var0);
      var10000 = algorithms;
      var0 = new DERObjectIdentifier.<init>("1.2.840.10045.4.1");
      var10000.put("ECDSAWITHSHA1", var0);
   }

   public X509V2CRLGenerator() {
      X509V2CRLGenerator var10000 = this;
      X509V2CRLGenerator var10001 = this;
      X509V2CRLGenerator var10002 = this;
      X509V2CRLGenerator var10003 = this;
      X509V2CRLGenerator var10004 = this;
      super();
      this.dateF = new SimpleDateFormat("yyMMddHHmmss");
      SimpleTimeZone var1;
      SimpleTimeZone var10005 = var1 = new SimpleTimeZone;
      var10005.<init>(0, "Z");
      var10004.tz = var10005;
      var10003.extensions = null;
      var10002.extOrdering = null;
      var10001.dateF.setTimeZone(var1);
      var10000.tbsGen = new V2TBSCertListGenerator();
   }

   public void reset() {
      X509V2CRLGenerator var10000 = this;
      V2TBSCertListGenerator var1;
      var1 = new V2TBSCertListGenerator.<init>();
      var10000.tbsGen = var1;
   }

   public void setIssuerDN(X509Name issuer) {
      this.tbsGen.setIssuer(issuer);
   }

   public void setThisUpdate(Date date) {
      this.tbsGen.setThisUpdate(new DERUTCTime(this.dateF.format(date) + "Z"));
   }

   public void setNextUpdate(Date date) {
      this.tbsGen.setNextUpdate(new DERUTCTime(this.dateF.format(date) + "Z"));
   }

   public void addCRLEntry(BigInteger userCertificate, Date revocationDate, int reason) {
      V2TBSCertListGenerator var10000 = this.tbsGen;
      DERInteger var10001 = new DERInteger(userCertificate);
      DERUTCTime userCertificate1;
      userCertificate1 = new DERUTCTime.<init>(this.dateF.format(revocationDate) + "Z");
      var10000.addCRLEntry(var10001, userCertificate1, reason);
   }

   public void setSignatureAlgorithm(String signatureAlgorithm) {
      this.signatureAlgorithm = signatureAlgorithm;
      DERObjectIdentifier signatureAlgorithm1;
      DERObjectIdentifier var10000 = signatureAlgorithm1 = (DERObjectIdentifier)algorithms.get(Strings.toUpperCase(signatureAlgorithm));
      this.sigOID = signatureAlgorithm1;
      if (var10000 != null) {
         X509V2CRLGenerator var2 = this;
         X509V2CRLGenerator var10001 = this;
         AlgorithmIdentifier var3;
         AlgorithmIdentifier var10002 = var3 = new AlgorithmIdentifier;
         var10002.<init>(signatureAlgorithm1, (DEREncodable)null);
         var10001.sigAlgId = var10002;
         var2.tbsGen.setSignature(var3);
      } else {
         throw new IllegalArgumentException("Unknown signature type requested");
      }
   }

   public void addExtension(String OID, boolean critical, DEREncodable value) {
      X509V2CRLGenerator var10000 = this;
      DERObjectIdentifier var4;
      var4 = new DERObjectIdentifier.<init>(OID);
      var10000.addExtension(var4, critical, value);
   }

   public void addExtension(DERObjectIdentifier OID, boolean critical, DEREncodable value) {
      if (this.extensions == null) {
         Hashtable var4;
         var4 = new Hashtable.<init>();
         this.extensions = var4;
         Vector var8;
         var8 = new Vector.<init>();
         this.extOrdering = var8;
      }

      X509V2CRLGenerator var10000 = this;
      ByteArrayOutputStream var6;
      ByteArrayOutputStream var10001 = var6 = new ByteArrayOutputStream;
      var10001.<init>();
      DEREncodable var10003 = value;
      DEROutputStream var10002 = new DEROutputStream(var6);

      try {
         var10002.writeObject(var10003);
      } catch (IOException var5) {
         throw new IllegalArgumentException("error encoding value: " + var5);
      }

      byte[] var7 = var10001.toByteArray();
      var10000.addExtension(OID, critical, var7);
   }

   public void addExtension(String OID, boolean critical, byte[] value) {
      X509V2CRLGenerator var10000 = this;
      DERObjectIdentifier var4;
      var4 = new DERObjectIdentifier.<init>(OID);
      var10000.addExtension(var4, critical, value);
   }

   public void addExtension(DERObjectIdentifier OID, boolean critical, byte[] value) {
      if (this.extensions == null) {
         Hashtable var4;
         var4 = new Hashtable.<init>();
         this.extensions = var4;
         Vector var7;
         var7 = new Vector.<init>();
         this.extOrdering = var7;
      }

      X509V2CRLGenerator var10000 = this;
      Hashtable var10001 = this.extensions;
      X509Extension var5;
      X509Extension var10003 = var5 = new X509Extension;
      boolean var10004 = critical;
      DEROctetString critical1;
      critical1 = new DEROctetString.<init>(value);
      var10003.<init>(var10004, critical1);
      var10001.put(OID, var5);
      var10000.extOrdering.addElement(OID);
   }

   public X509CRL generateX509CRL(PrivateKey key) {
      try {
         return this.generateX509CRL(key, "INFOSEC", (SecureRandom)null);
      } catch (NoSuchProviderException var2) {
         throw new SecurityException("BC provider not installed!");
      }
   }

   public X509CRL generateX509CRL(PrivateKey key, SecureRandom random) {
      try {
         return this.generateX509CRL(key, "INFOSEC", random);
      } catch (NoSuchProviderException var3) {
         throw new SecurityException("BC provider not installed!");
      }
   }

   public X509CRL generateX509CRL(PrivateKey key, String provider) {
      return this.generateX509CRL(key, provider, (SecureRandom)null);
   }

   public X509CRL generateX509CRL(PrivateKey key, String provider, SecureRandom random) {
      Signature var10000;
      try {
         var10000 = Signature.getInstance(this.sigOID.getId(), provider);
      } catch (NoSuchAlgorithmException var6) {
         try {
            var10000 = Signature.getInstance(this.signatureAlgorithm, provider);
         } catch (NoSuchAlgorithmException var5) {
            throw new SecurityException("exception creating signature: " + var5.toString());
         }
      }

      Signature provider1 = var10000;
      if (random != null) {
         provider1.initSign(key, random);
      } else {
         provider1.initSign(key);
      }

      if (this.extensions != null) {
         Vector key1 = this.extOrdering;
         this.tbsGen.setExtensions(new X509Extensions(key1, this.extensions));
      }

      var10000 = provider1;
      TBSCertList key2 = this.tbsGen.generateTBSCertList();

      label53: {
         Exception var17;
         label60: {
            ByteArrayOutputStream var16;
            boolean var10001;
            try {
               var16 = new ByteArrayOutputStream;
            } catch (Exception var9) {
               var17 = var9;
               var10001 = false;
               break label60;
            }

            ByteArrayOutputStream random1;
            ByteArrayOutputStream var10002 = random1 = var16;

            DEROutputStream var18;
            try {
               var10002.<init>();
               var18 = new DEROutputStream;
            } catch (Exception var8) {
               var17 = var8;
               var10001 = false;
               break label60;
            }

            DEROutputStream var10003 = var18;

            try {
               var10003.<init>(random1);
               var18.writeObject(key2);
               var10000.update(var16.toByteArray());
               break label53;
            } catch (Exception var7) {
               var17 = var7;
               var10001 = false;
            }
         }

         Exception var10 = var17;
         throw new SecurityException("exception encoding TBS cert - " + var10);
      }

      ASN1EncodableVector random2;
      ASN1EncodableVector var19 = random2 = new ASN1EncodableVector;
      random2.<init>();
      random2.add(key2);
      var19.add(this.sigAlgId);
      var19.add(new DERBitString(provider1.sign()));

      try {
         return new X509CRLObject(new CertificateList(new DERSequence(random2)));
      } catch (CRLException var4) {
         throw new IllegalStateException("attempt to create malformed CRL: " + var4.getMessage());
      }
   }
}
